==> zio-aws-securitylake_3-6.20.78.1-sources.jar: zio/aws/securitylake/model/CreateDataLakeRequest.scala <==
package zio.aws.securitylake.model
import zio.aws.securitylake.model.primitives.RoleArn
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class CreateDataLakeRequest(
    configurations: Iterable[zio.aws.securitylake.model.DataLakeConfiguration],
    metaStoreManagerRoleArn: RoleArn
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securitylake.model.CreateDataLakeRequest = {
    import CreateDataLakeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securitylake.model.CreateDataLakeRequest
      .builder()
      .configurations(configurations.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .metaStoreManagerRoleArn(
        RoleArn.unwrap(metaStoreManagerRoleArn): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.securitylake.model.CreateDataLakeRequest.ReadOnly =
    zio.aws.securitylake.model.CreateDataLakeRequest.wrap(buildAwsValue())
}
object CreateDataLakeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securitylake.model.CreateDataLakeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securitylake.model.CreateDataLakeRequest =
      zio.aws.securitylake.model.CreateDataLakeRequest(
        configurations.map { item =>
          item.asEditable
        },
        metaStoreManagerRoleArn
      )
    def configurations
        : List[zio.aws.securitylake.model.DataLakeConfiguration.ReadOnly]
    def metaStoreManagerRoleArn: RoleArn
    def getConfigurations: ZIO[Any, Nothing, List[
      zio.aws.securitylake.model.DataLakeConfiguration.ReadOnly
    ]] = ZIO.succeed(configurations)
    def getMetaStoreManagerRoleArn: ZIO[Any, Nothing, RoleArn] =
      ZIO.succeed(metaStoreManagerRoleArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securitylake.model.CreateDataLakeRequest
  ) extends zio.aws.securitylake.model.CreateDataLakeRequest.ReadOnly {
    override val configurations
        : List[zio.aws.securitylake.model.DataLakeConfiguration.ReadOnly] = impl
      .configurations()
      .asScala
      .map { item =>
        zio.aws.securitylake.model.DataLakeConfiguration.wrap(item)
      }
      .toList
    override val metaStoreManagerRoleArn: RoleArn =
      zio.aws.securitylake.model.primitives
        .RoleArn(impl.metaStoreManagerRoleArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.securitylake.model.CreateDataLakeRequest
  ): zio.aws.securitylake.model.CreateDataLakeRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-securitylake_3-6.20.115.2-sources.jar: zio/aws/securitylake/model/CreateDataLakeRequest.scala <==
package zio.aws.securitylake.model
import zio.aws.securitylake.model.primitives.RoleArn
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateDataLakeRequest(
    configurations: Iterable[zio.aws.securitylake.model.DataLakeConfiguration],
    metaStoreManagerRoleArn: RoleArn,
    tags: Optional[Iterable[zio.aws.securitylake.model.Tag]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securitylake.model.CreateDataLakeRequest = {
    import CreateDataLakeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securitylake.model.CreateDataLakeRequest
      .builder()
      .configurations(configurations.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .metaStoreManagerRoleArn(
        RoleArn.unwrap(metaStoreManagerRoleArn): java.lang.String
      )
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.securitylake.model.CreateDataLakeRequest.ReadOnly =
    zio.aws.securitylake.model.CreateDataLakeRequest.wrap(buildAwsValue())
}
object CreateDataLakeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securitylake.model.CreateDataLakeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securitylake.model.CreateDataLakeRequest =
      zio.aws.securitylake.model.CreateDataLakeRequest(
        configurations.map { item =>
          item.asEditable
        },
        metaStoreManagerRoleArn,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def configurations
        : List[zio.aws.securitylake.model.DataLakeConfiguration.ReadOnly]
    def metaStoreManagerRoleArn: RoleArn
    def tags: Optional[List[zio.aws.securitylake.model.Tag.ReadOnly]]
    def getConfigurations: ZIO[Any, Nothing, List[
      zio.aws.securitylake.model.DataLakeConfiguration.ReadOnly
    ]] = ZIO.succeed(configurations)
    def getMetaStoreManagerRoleArn: ZIO[Any, Nothing, RoleArn] =
      ZIO.succeed(metaStoreManagerRoleArn)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.securitylake.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securitylake.model.CreateDataLakeRequest
  ) extends zio.aws.securitylake.model.CreateDataLakeRequest.ReadOnly {
    override val configurations
        : List[zio.aws.securitylake.model.DataLakeConfiguration.ReadOnly] = impl
      .configurations()
      .asScala
      .map { item =>
        zio.aws.securitylake.model.DataLakeConfiguration.wrap(item)
      }
      .toList
    override val metaStoreManagerRoleArn: RoleArn =
      zio.aws.securitylake.model.primitives
        .RoleArn(impl.metaStoreManagerRoleArn())
    override val tags: Optional[List[zio.aws.securitylake.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.securitylake.model.Tag.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.securitylake.model.CreateDataLakeRequest
  ): zio.aws.securitylake.model.CreateDataLakeRequest.ReadOnly = new Wrapper(
    impl
  )
}
